@@ -17,6 +17,7 @@ import testtools
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests import share_exceptions
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests import utils
@@ -36,7 +37,8 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
             raise cls.skipException(
                 'Only for driver_handles_share_servers = False driver mode.')
 
-        utils.check_skip_if_microversion_lt(_MIN_SUPPORTED_MICROVERSION)
+        utils.check_skip_if_microversion_not_supported(
+            _MIN_SUPPORTED_MICROVERSION)
 
     @classmethod
     def resource_setup(cls):
@@ -54,13 +56,15 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
 
         # create share type
         extra_specs = {"replication_type": cls.replication_type}
-        cls.share_type = cls._create_share_type(specs=extra_specs)
+        if CONF.share.capability_snapshot_support:
+            extra_specs.update({"snapshot_support": True})
+        cls.share_type = cls.create_share_type(extra_specs=extra_specs)
         cls.share_type_id = cls.share_type['id']
 
         cls.sn_id = None
         if cls.multitenancy_enabled:
             cls.share_network = cls.shares_v2_client.get_share_network(
-                cls.shares_v2_client.share_network_id)
+                cls.shares_v2_client.share_network_id)['share_network']
             cls.sn_id = cls.share_network['id']
 
         cls.zones = cls.get_availability_zones_matching_share_type(
@@ -75,7 +79,7 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
                                      share_network_id=cls.sn_id,
                                      client=cls.admin_client)
         cls.replica = cls.admin_client.list_share_replicas(
-            share_id=cls.share['id'])[0]
+            share_id=cls.share['id'])['share_replicas'][0]
 
     @decorators.idempotent_id('b39f319e-2515-42c0-85c4-21c2fb2123bf')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
@@ -85,9 +89,9 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
         # Test extend share
         new_size = self.share["size"] + 1
         self.admin_client.extend_share(self.share["id"], new_size)
-        self.admin_client.wait_for_share_status(self.share["id"],
-                                                "available")
-        share = self.admin_client.get_share(self.share["id"])
+        waiters.wait_for_resource_status(
+            self.admin_client, self.share["id"], "available")
+        share = self.admin_client.get_share(self.share["id"])['share']
         self.assertEqual(new_size, int(share["size"]))
 
     @decorators.idempotent_id('743bfb8e-a314-4e8e-92b5-079bd3eae72d')
@@ -95,11 +99,12 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
     @testtools.skipUnless(CONF.share.run_shrink_tests,
                           'Shrink share tests are disabled.')
     def test_shrink_replicated_share(self):
-        share = self.admin_client.get_share(self.share["id"])
+        share = self.admin_client.get_share(self.share["id"])['share']
         new_size = self.share["size"] - 1
         self.admin_client.shrink_share(self.share["id"], new_size)
-        self.admin_client.wait_for_share_status(share["id"], "available")
-        shrink_share = self.admin_client.get_share(self.share["id"])
+        waiters.wait_for_resource_status(
+            self.admin_client, share["id"], "available")
+        shrink_share = self.admin_client.get_share(self.share["id"])['share']
         self.assertEqual(new_size, int(shrink_share["size"]))
 
     @decorators.idempotent_id('84150cd6-2777-4806-8aa3-51359f16816e')
@@ -109,15 +114,15 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
     def test_manage_share_for_replication_type(self):
         """Manage a share with replication share type."""
         # Create a share and unmanage it
-        share = self.create_share(size=2,
+        share = self.create_share(size=CONF.share.share_size,
                                   share_type_id=self.share_type_id,
                                   availability_zone=self.share_zone,
                                   share_network_id=self.sn_id,
                                   cleanup_in_class=True,
                                   client=self.admin_client)
-        share = self.admin_client.get_share(share["id"])
+        share = self.admin_client.get_share(share["id"])['share']
         export_locations = self.admin_client.list_share_export_locations(
-            share["id"])
+            share["id"])['export_locations']
         export_path = export_locations[0]['path']
 
         self.admin_client.unmanage_share(share['id'])
@@ -126,9 +131,9 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
         # Manage the previously unmanaged share
         managed_share = self.admin_client.manage_share(
             share['host'], share['share_proto'],
-            export_path, self.share_type_id)
-        self.admin_client.wait_for_share_status(
-            managed_share['id'], 'available')
+            export_path, self.share_type_id)['share']
+        waiters.wait_for_resource_status(
+            self.admin_client, managed_share['id'], 'available')
 
         # Add managed share to cleanup queue
         self.method_resources.insert(
@@ -159,7 +164,7 @@ class ReplicationActionsAdminTest(base.BaseSharesMixedTest):
                           'Manage/Unmanage Tests are disabled.')
     def test_unmanage_replicated_share_with_no_replica(self):
         """Unmanage a replication type share that does not have replica."""
-        share = self.create_share(size=2,
+        share = self.create_share(size=CONF.share.share_size,
                                   share_type_id=self.share_type_id,
                                   share_network_id=self.sn_id,
                                   availability_zone=self.share_zone,
