@@ -49,6 +49,8 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
     def setup_clients(cls):
         super(ShareScenarioTest, cls).setup_clients()
 
+        cls.compute_floating_ips_client = (
+            cls.os_primary.compute_floating_ips_client)
         # Manila clients
         cls.shares_client = cls.os_primary.share_v1.SharesClient()
         cls.shares_v2_client = cls.os_primary.share_v2.SharesV2Client()
@@ -108,19 +110,19 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
 
         # Tests need to be able to ssh into the VM - so we need
         # a security group, and a tenant private network
-        self.security_group = self._create_security_group()
-        self.network = self._create_network(namestart="manila-share")
+        self.security_group = self.create_security_group()
+        self.network = self.create_network(namestart="manila-share")
         # When not using a "storage network" to connect shares to VMs,
         # we need the subnet to match the IP version we're testing
         subnet_ip_params = {} if self.storage_network else {
             'ip_version': self.ip_version,
             'use_default_subnetpool': self.ipv6_enabled
         }
-        self.subnet = self._create_subnet(
+        self.subnet = self.create_subnet(
             network=self.network,
             namestart="manila-share-sub",
             **subnet_ip_params)
-        router = self._get_router()
+        router = self.get_router()
         self._create_router_interface(subnet_id=self.subnet['id'],
                                       router_id=router['id'])
 
@@ -192,7 +194,8 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         remote_client = self.get_remote_client(
             server_or_ip=server_ip,
             username=self.ssh_user,
-            private_key=self.keypair['private_key'])
+            private_key=self.keypair['private_key'],
+            server=instance)
 
         # NOTE(u_glide): Workaround for bug #1465682
         remote_client = remote_client.ssh_client
@@ -307,7 +310,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
             linux_client.validate_authentication()
         except Exception:
             LOG.exception('Initializing SSH connection to %s failed', ip)
-            self._log_console_output()
+            self.log_console_output()
             raise
 
         return linux_client
@@ -637,7 +640,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         if not client:
             client = self.routers_client
         if not router_id:
-            router_id = self._get_router()['id']
+            router_id = self.get_router()['id']
         client.add_router_interface(router_id, subnet_id=subnet_id)
         self.addCleanup(
             client.remove_router_interface, router_id, subnet_id=subnet_id)
